@@ -87,8 +87,8 @@ from bzrlib.plugins.explorer.lib.compatibility import send2trash
 
 _LP_PROJECT = "bzr-explorer"
 _HELP_URL = "http://doc.bazaar.canonical.com/explorer/en/documentation.html"
-_CODE_NAME = "Leif Ericson"
-_CODE_NAME_URL = "http://en.wikipedia.org/wiki/Leif_Ericson"
+_CODE_NAME = "James Cook"
+_CODE_NAME_URL = "http://en.wikipedia.org/wiki/James_Cook"
 
 
 _MSG_TYPE_TO_ICON = {
@@ -250,7 +250,10 @@ class QExplorerMainWindow(QBzrWindow):
         """Call this after editing bazaar.conf."""
         if self._user_config is None:
             # first time load
-            self._user_config = config.GlobalConfig()
+            try:
+                self._user_config = config.GlobalStack()
+            except AttributeError: # bzr < 2.6
+                self._user_config = config.GlobalConfig()
         else:
             # reload the data
             helpers.reload_config_obj(self._user_config,
@@ -262,7 +265,10 @@ class QExplorerMainWindow(QBzrWindow):
             }
 
     def get_default_editor(self):
-        result = self._user_config.get_editor()
+        try:
+            result = self._user_config.get('editor')
+        except AttributeError: # bzr < 2.6
+            result = self._user_config.get_editor()
         if result is not None:
             result = result.strip()
         return result or self.desktop_env.default_editor()
@@ -1604,7 +1610,14 @@ class QExplorerMainWindow(QBzrWindow):
             self.open_location(new_location)
 
     def _start_checkout(self, context=None):
-        return custom_dialog_registry.get('checkout')(parent=self)
+        from_location = None
+        if context:
+            from_location = context.get('branch_root')
+            if from_location and from_location.startswith("file://"):
+                from_location = urlutils.local_path_from_url(from_location)
+        dialog = custom_dialog_registry.get('checkout')
+        lightweight = self._preferences.get('lightweight-checkout-by-default')
+        return dialog(from_location, parent=self, lightweight=lightweight)
 
     def _finish_checkout(self):
         dialog = self._custom_modeless_dialogs['checkout']
