@@ -12,7 +12,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
 
 import sys
 
@@ -47,6 +47,7 @@ DEFAULT_PREFERENCES = {
     "workingtree-style": "qbrowse",
     "workspace-model": "feature-branches",
     "bind-branches-by-default": False,
+    "lightweight-checkout-by-default": False,
     "location-selector-style": "tabs",
     "clothes-to-wear": [
         "Bazaar support",
@@ -68,6 +69,7 @@ _BOOLEAN_PREFERENCES = [
     "custom-dialog-switch",
     "advanced-commands-terminal",
     "bind-branches-by-default",
+    "lightweight-checkout-by-default",
     "toolbox-on-status-view",
     "toolbox-on-repository-view",
     "toolbox-on-welcome-view",
@@ -342,9 +344,13 @@ class ExplorerPreferencesDialog(QtGui.QDialog):
         bind_branches_cb = self._build_checkbox_field(
             "bind-branches-by-default",
             gettext("Bind branches by default"))
+        checkout_branches_cb = self._build_checkbox_field(
+            "lightweight-checkout-by-default",
+            gettext("Lightweight checkout by default"))
         defaults_layout = QtGui.QFormLayout()
         defaults_layout.addRow(gettext("Workspace Model"), ws_model_combo)
         defaults_layout.addRow(bind_branches_cb)
+        defaults_layout.addRow(checkout_branches_cb)
         defaults_group = QtGui.QGroupBox(gettext(
             "Default Values in Dialogs"))
         defaults_group.setLayout(defaults_layout)
