@@ -17,7 +17,11 @@
 
 from urlparse import urlsplit, urlunsplit
 
-from bzrlib.plugins.launchpad import cmd_launchpad_open
+from bzrlib import errors
+try:
+    from bzrlib.plugins.launchpad.cmds import cmd_launchpad_open
+except ImportError: # bzr < 2.6
+    from bzrlib.plugins.launchpad import cmd_launchpad_open
 from bzrlib.plugins.launchpad.lp_registration import (
     LaunchpadService,
     NotLaunchpadBranch,
@@ -44,6 +48,8 @@ class HostedUrlResolver(object):
             return self._lp_open_cmd._get_web_url(self._lp_service, location)
         except NotLaunchpadBranch:
             return None
+        except errors.SocketConnectionError:    # workaround for bug #925951
+            return None
 
     def get_project_url(self, location='.'):
         """Get the web project URL for a given location.
@@ -56,6 +62,8 @@ class HostedUrlResolver(object):
             branch_url = self._lp_open_cmd._get_web_url(self._lp_service, location)
         except NotLaunchpadBranch:
             return None
+        except errors.SocketConnectionError:    # workaround for bug #925951
+            return None
 
         # We found an lp branch. The format ought to be
         # https://code.xxx/~user-id/project-name/branch-name/.
