@@ -12,7 +12,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
 
 
 from PyQt4 import QtCore, QtGui
@@ -22,6 +22,7 @@ from bzrlib.plugins.explorer.lib import (
     kinds,
     location,
     )
+from bzrlib.plugins.explorer.lib.i18n import gettext, N_
 
 
 class LocationSelector(QtCore.QObject):
@@ -57,6 +58,14 @@ class LocationSelector(QtCore.QObject):
           a QWidget or None.
         """
         return None, None, None, None
+    
+    def ui_resizable(self):
+        """Returns whether each decorator widget should be resizable.
+        
+        :return: north_resize, east_resize, west_resize, south_resize where
+          each item is a boolean.
+        """
+        return False, False, False, False
 
     def _init_data(self):
         """Initialise subclass specific attributes."""
@@ -123,6 +132,7 @@ class TabsLocationSelector(LocationSelector):
         key = unicode(self._tabs.tabData(index).toString())
         self._tabs.removeTab(index)
         del self._model_by_key[key]
+        self.emit(QtCore.SIGNAL("locationDeleted"), key)
 
     def update_current_label(self):
         """Update the text/icon/tooltip for the current location."""
@@ -197,6 +207,7 @@ class _ComboBoxLocationSelector(LocationSelector):
         key = unicode(self._combo.itemData(index).toString())
         self._combo.removeItem(index)
         del self._model_by_key[key]
+        self.emit(QtCore.SIGNAL("locationDeleted"), key)
 
     def update_current_label(self):
         """Update the text/icon/tooltip for the current location."""
@@ -407,11 +418,13 @@ class TabGroupsLocationSelector(LocationSelector):
             tabs.removeTab(tab_index)
             if combo_key != tab_key:
                 del self._model_by_key[tab_key]
+                self.emit(QtCore.SIGNAL("locationDeleted"), tab_key)
         if tabs.count() <= 0:
             self._combo.removeItem(combo_index)
             self._stack.removeWidget(tabs)
             del self._model_by_key[combo_key]
             del self._tabs_for_group[combo_key]
+            self.emit(QtCore.SIGNAL("locationDeleted"), combo_key)
 
     def update_current_label(self):
         """Update the text/icon/tooltip for the current location."""
@@ -442,10 +455,160 @@ class TabGroupsLocationSelector(LocationSelector):
             tabs.setCurrentIndex(self._find_tab_index(tabs, key))
 
 
+class TreeLocationSelector(LocationSelector):
+    """Select locations arranged in a tree."""
+
+    def _init_data(self):
+        self._model_by_key = {}
+        self._items_for_group = {}
+
+    def ui_decorators(self):
+        """Returns a tuple of widgets for each border (N.E.W.S)."""
+        ui = QtGui.QWidget()
+        ui.setLayout(self._layout_ui())
+        return None, None, ui, None
+    
+    def ui_resizable(self):
+        return False, False, True, False
+
+    def _layout_ui(self):
+        label = QtGui.QLabel(gettext("Locations"))
+        label.setFrameShape(QtGui.QFrame.Box)
+        label.setFrameShadow(QtGui.QFrame.Sunken)
+        self._tree = self._build_tree()
+        layout = QtGui.QVBoxLayout()
+        layout.addWidget(label)
+        layout.addWidget(self._tree)
+        layout.setContentsMargins(0, 0, 0, 0)
+        return layout
+
+    def _build_tree(self):
+        tree = QtGui.QTreeWidget()
+        tree.setColumnCount(1)
+        tree.headerItem().setHidden(True)
+        tree.addActions([self._action_map["close"]])
+        tree.setContextMenuPolicy(QtCore.Qt.ActionsContextMenu)
+        self.connect(tree, QtCore.SIGNAL(
+            "currentItemChanged(QTreeWidgetItem*,QTreeWidgetItem*)"),
+            self._changed_current)
+        return tree
+
+    def _changed_current(self, current, previous):
+        key = None
+        model = None
+        if current:
+            key = unicode(current.data(0, QtCore.Qt.UserRole).toString())
+            if key:
+                model = self._model_by_key[key]
+        self.emit(QtCore.SIGNAL("currentChanged"), key, model)
+
+    def add_location(self, key, model):
+        """Add an entry for a location."""
+        self._model_by_key[key] = model
+        group_key = self._get_group_key(model)
+        if group_key is None:
+            item = self._add_group(key, model)
+        else:
+            try:
+                group_model = self._model_by_key[group_key]
+            except KeyError:
+                # group model doesn't exist yet, so create it
+                group_model = self._build_group_model(group_key, model)
+            item = self._add_group(group_key, group_model)
+            if model.kind() != kinds.REPOSITORY_KIND and \
+                    group_model.kind() in (kinds.REPOSITORY_KIND,
+                                           kinds.VIRTUAL_REPO_KIND):
+                item = self._add_group_child(item, key, model)
+        self._tree.setCurrentItem(item)
+
+    def _add_group(self, key, model):
+        try:
+            item = self._items_for_group[key]
+        except KeyError:
+            item = QtGui.QTreeWidgetItem()
+            item.setIcon(0, model.display_icon())
+            item.setText(0, model.display_name())
+            item.setData(0, QtCore.Qt.UserRole, QtCore.QVariant(key))
+            item.setData(0, QtCore.Qt.ToolTipRole,
+                         QtCore.QVariant(model.display_tooltip()))
+            self._items_for_group[key] = item
+            self._tree.addTopLevelItem(item)
+        return item
+    
+    def _add_group_child(self, group_item, key, model):
+        item = QtGui.QTreeWidgetItem()
+        item.setIcon(0, model.display_icon())
+        item.setText(0, model.display_local_name())
+        item.setData(0, QtCore.Qt.UserRole, QtCore.QVariant(key))
+        item.setData(0, QtCore.Qt.ToolTipRole,
+                     QtCore.QVariant(model.display_tooltip()))
+        group_item.addChild(item)
+        return item
+    
+    def _get_group_key(self, model):
+        """Return the group key for an item or None if none."""
+        group = model.group()
+        if group is not None and group.startswith("file://"):
+            group = urlutils.local_path_from_url(group)
+        return group
+
+    def _build_group_model(self, group_key, item_model):
+        action_callback = item_model.action_callback
+        dry_run = item_model.dry_run
+        model = location.LocationModel(group_key, action_callback, dry_run)
+        self._model_by_key[group_key] = model
+        return model
+
+    def close_current(self):
+        """Close the current location."""
+        item = self._tree.currentItem()
+        key = unicode(item.data(0, QtCore.Qt.UserRole).toString())
+        if item.parent():
+            item.parent().removeChild(item)
+        else:
+            for child in item.takeChildren():
+                child_key = unicode(child.data(0, QtCore.Qt.UserRole).toString())
+                del self._model_by_key[child_key]
+                self.emit(QtCore.SIGNAL("locationDeleted"), child_key)
+            self._tree.takeTopLevelItem(self._tree.indexOfTopLevelItem(item))
+            del self._items_for_group[key]
+        del self._model_by_key[key]
+        self.emit(QtCore.SIGNAL("locationDeleted"), key)
+
+    def update_current_label(self):
+        """Update the text/icon/tooltip for the current location."""
+        item, model = self._get_current_item_and_model()
+        if item.parent():
+            item.setText(0, model.display_local_name())
+        else:
+            item.setText(0, model.display_name())
+        item.setIcon(0, model.display_icon())
+        item.setData(0, QtCore.Qt.ToolTipRole,
+                     QtCore.QVariant(model.display_tooltip()))
+
+    def _get_current_item_and_model(self):
+        item = self._tree.currentItem()
+        key = unicode(item.data(0, QtCore.Qt.UserRole).toString())
+        model = self._model_by_key[key]
+        return item, model
+
+    def select_key(self, key):
+        """Select the given key. Raises KeyError if not found."""
+        iter = QtGui.QTreeWidgetItemIterator(self._tree)
+        while iter.value():
+            item = iter.value()
+            this_key = unicode(item.data(0, QtCore.Qt.UserRole).toString())
+            if key == this_key:
+                self._tree.setCurrentItem(item)
+                return
+            iter += 1
+        else:
+            raise KeyError(key)
 
 ## The location selector registry ##
 
 location_selector_registry = registry.Registry()
 location_selector_registry.register("tabs", TabsLocationSelector)
 location_selector_registry.register("tab-groups", TabGroupsLocationSelector)
+location_selector_registry.register("tree", TreeLocationSelector)
 location_selector_registry.default_key = "tabs"
