@@ -12,7 +12,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
 
 """Helper routines for collecting status data.
 
@@ -107,11 +107,30 @@ def get_submission_info(branch):
     return changes_between_trees(new_tree, old_tree)[0]
 
 def get_parent_submission_info(branch):
-    """Get the status information for a branch versus its submit branch.
+    """Get the status information for a branch versus its parent branch.
+
+    We get delta as equivalent of bzr command:
+        bzr status -r ancestor::parent..-1
+
+    We use common ancestor of both branches as base revision to make sure
+    we only show changes made in this branch and exclude side-effects
+    of changes made in parent branch (see bug #956268 for details).
 
     :return: delta
     """
     new_tree = branch.basis_tree()
     old_branch = mod_branch.Branch.open_containing(branch.get_parent())[0]
-    old_tree = old_branch.basis_tree()
-    return changes_between_trees(new_tree, old_tree)[0]
+    branch.lock_read()
+    old_branch.lock_read()
+    try:
+        # Thanks to Aaron for code snippet
+        # Get a graph, so we can find the common ancestor (LCA)
+        graph = old_branch.repository.get_graph(branch.repository)
+        # Find the LCA of the revisions (equivalent of `-r ancestor::parent`)
+        lca = graph.find_unique_lca(branch.last_revision(),
+                                    old_branch.last_revision())
+        old_tree = old_branch.repository.revision_tree(lca)
+        return changes_between_trees(new_tree, old_tree)[0]
+    finally:
+        old_branch.unlock()
+        branch.unlock()
