@@ -35,6 +35,7 @@ from bzrlib.plugins.explorer.lib.kinds import (
     html_status_message,
     )
 from bzrlib.plugins.explorer.lib.status_report import StatusReport
+from bzrlib.plugins.explorer.lib.filesystemwatcher import QFileSystemWatcher
 from bzrlib.plugins.explorer.widgets import (
     conditional_dataview,
     tab_widget,
@@ -193,7 +194,7 @@ class _RepositoryViewBase(object):
         repo_url = root_transport.external_url()
         if repo_url.startswith("file://"):
             repo_path = urlutils.local_path_from_url(repo_url)
-            directory_watcher = QtCore.QFileSystemWatcher(
+            directory_watcher = QFileSystemWatcher(
                                        [QtCore.QString(repo_path)], self._view)
             directory_watcher.directoryChanged.connect(
                                         self._repo_directory_changed)
