@@ -22,9 +22,11 @@ from bzrlib.plugins.explorer.lib import (
     view_submit,
     )
 from bzrlib.plugins.explorer.lib.i18n import gettext, N_
+from bzrlib.plugins.explorer.lib.filesystemwatcher import QFileSystemWatcher
 from bzrlib import urlutils, osutils
 from bzrlib.errors import LockContention, NotLocalUrl
 
+
 class WorkingTreeView(QtCore.QObject):
     """The default view for branches & checkouts with working trees."""
 
@@ -69,7 +71,7 @@ class WorkingTreeView(QtCore.QObject):
 
         # TODO: add other panels to show what's on the shelf, etc.
 
-        self.file_watcher = QtCore.QFileSystemWatcher()
+        self.file_watcher = QFileSystemWatcher()
         self.file_watcher.directoryChanged.connect(
                                                 self._branch_directory_changed)
         self._add_file_watcher_paths()
@@ -111,7 +113,6 @@ class WorkingTreeView(QtCore.QObject):
             root = self.model.branch.user_transport.local_abspath(".")
         except NotLocalUrl:
             return []
-        print "root: " + root
         result = []
         for (dir_info, dir_entries) in osutils._walkdirs_utf8(root):
             utf8_relpath, system_path = dir_info
